nx.geometry.Vector - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.geometry.Vector Class

Module: nx.geometry

- Index
- Methods

## Item Index

### Methods

- add
- angle
- circumferentialAngle
- clone
- divide
- equals
- length
- multiply
- negate
- normal
- normalize
- rotate
- slope
- squaredLength
- subtract

## Methods

### `add`

(

- `v`

)
nx.geometry.Vector

#### Parameters:

- `v` nx.geometry.Vector

#### Returns:

nx.geometry.Vector:

### `angle`

() Number

#### Returns:

Number:

### `circumferentialAngle`

() Number

#### Returns:

Number:

### `clone`

() nx.geometry.Vector

#### Returns:

nx.geometry.Vector:

### `divide`

(

- `k`

)
nx.geometry.Vector

#### Parameters:

- `k` Number

#### Returns:

nx.geometry.Vector:

### `equals`

(

- `v`

)
Boolean

#### Parameters:

- `v` nx.geometry.Vector

#### Returns:

Boolean:

### `length`

() Number

#### Returns:

Number:

### `multiply`

(

- `k`

)
nx.geometry.Vector

#### Parameters:

- `k` Number

#### Returns:

nx.geometry.Vector:

### `negate`

() nx.geometry.Vector

#### Returns:

nx.geometry.Vector:

### `normal`

() nx.geometry.Vector

#### Returns:

nx.geometry.Vector:

### `normalize`

() nx.geometry.Vector

#### Returns:

nx.geometry.Vector:

### `rotate`

(

- `a`

)
nx.geometry.Vector

#### Parameters:

- `a` Number

#### Returns:

nx.geometry.Vector:

### `slope`

() Number

#### Returns:

Number:

### `squaredLength`

() Number

#### Returns:

Number:

### `subtract`

(

- `v`

)
nx.geometry.Vector

#### Parameters:

- `v` nx.geometry.Vector

#### Returns:

nx.geometry.Vector: